@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -154,9 +154,9 @@ sub detect_perinci_cmdline_script {
                     "so it's unsafe to parse",
                 );
             } else {
-                require JSON;
+                require JSON::MaybeXS;
                 eval { $pericmd_inline_attrs =
-                           JSON::decode_json($pericmd_inline_attrs) };
+                           JSON::MaybeXS::decode_json($pericmd_inline_attrs) };
                 if ($@) {
                     push @{ $meta->{'func.notes'} },
                         "Can't parse # PERICMD_INLINE_SCRIPT attributes: $@";
@@ -192,7 +192,7 @@ Perinci::CmdLine::Util - Utility routines related to Perinci::CmdLine
 
 =head1 VERSION
 
-This document describes version 0.08 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2015-09-03.
+This document describes version 0.09 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
@@ -221,6 +221,8 @@ something like C<use Perinci::CmdLine>;
 
 =back
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -256,10 +258,6 @@ Return value:  (any)
 
 =for Pod::Coverage ^()$
 
-=head1 SEE ALSO
-
-L<Perinci::CmdLine>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Util>.
@@ -276,13 +274,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci::CmdLine>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
